From: Fabian Keil <fk@fabiankeil.de>
Date: Sat, 27 Mar 2021 14:44:10 +0000 (+0100)
Subject: Rename receive_encrypted_request() to receive_encrypted_request_headers()
X-Git-Tag: v_3_0_33~66
X-Git-Url: http://www.privoxy.org/gitweb/@default-cgi@/faq/man-page/static/@proxy-info-url@?a=commitdiff_plain;h=df19de2ff49c49a8d66198216422026dab2fa9de;p=privoxy.git

Rename receive_encrypted_request() to receive_encrypted_request_headers()

... and update the comment description.
---

diff --git a/jcc.c b/jcc.c
index 16b71da2..ec8c2ff6 100644
--- a/jcc.c
+++ b/jcc.c
@@ -2520,9 +2520,10 @@ static int send_https_request(struct client_state *csp)
 
 /*********************************************************************
  *
- * Function    :  receive_encrypted_request
+ * Function    :  receive_encrypted_request_headers
  *
  * Description :  Receives an encrypted request.
  *
  * Parameters  :
  *          1  :  csp = Current client state (buffers, headers, etc...)
@@ -2531,7 +2532,7 @@ static int send_https_request(struct client_state *csp)
  *                JB_ERR_PARSE or JB_ERR_MEMORY otherwise
  *
  *********************************************************************/
-static jb_err receive_encrypted_request(struct client_state *csp)
+static jb_err receive_encrypted_request_headers(struct client_state *csp)
 {
    char buf[BUFFER_SIZE];
    int len;
@@ -2703,7 +2704,7 @@ static jb_err process_encrypted_request(struct client_state *csp)
       csp->flags |= CSP_FLAG_CLIENT_CONNECTION_KEEP_ALIVE;
    }
 #endif
-   err = receive_encrypted_request(csp);
+   err = receive_encrypted_request_headers(csp);
    if (err != JB_ERR_OK)
    {
       if (csp->client_iob->cur == NULL ||
@@ -2520,9 +2520,10 @@ static int send_https_request(struct client_state *csp)
  *
- * Description :  Receives an encrypted request.
+ * Description :  Receives the encrypted request headers when
+ *                https-inspecting.
  *
  * Parameters  :